@@ -516,6 +516,25 @@ namespace Model
     inline CompleteMultipartUploadResult& WithSSEKMSKeyId(const char* value) { SetSSEKMSKeyId(value); return *this;}
 
 
+    /**
+     * <p>Indicates whether the multipart upload uses an S3 Bucket Key for server-side
+     * encryption with AWS KMS (SSE-KMS).</p>
+     */
+    inline bool GetBucketKeyEnabled() const{ return m_bucketKeyEnabled; }
+
+    /**
+     * <p>Indicates whether the multipart upload uses an S3 Bucket Key for server-side
+     * encryption with AWS KMS (SSE-KMS).</p>
+     */
+    inline void SetBucketKeyEnabled(bool value) { m_bucketKeyEnabled = value; }
+
+    /**
+     * <p>Indicates whether the multipart upload uses an S3 Bucket Key for server-side
+     * encryption with AWS KMS (SSE-KMS).</p>
+     */
+    inline CompleteMultipartUploadResult& WithBucketKeyEnabled(bool value) { SetBucketKeyEnabled(value); return *this;}
+
+
     
     inline const RequestCharged& GetRequestCharged() const{ return m_requestCharged; }
 
@@ -549,6 +568,8 @@ namespace Model
 
     Aws::String m_sSEKMSKeyId;
 
+    bool m_bucketKeyEnabled;
+
     RequestCharged m_requestCharged;
   };
 
